@@ -1,11 +1,10 @@
 """Functions to read and parse osef files/streams."""
 import socket
-import sys
 import time
 import traceback
 from collections import namedtuple, deque
 from itertools import islice
-from struct import Struct, error
+from struct import Struct
 from typing import Any, Iterable, Optional, Tuple, Iterator
 from urllib.parse import urlparse
 import logging
@@ -60,21 +59,39 @@ class OsefStream:
 
         return self._io_stream.read(size)
 
-    def open_socket(self):
+    def open_socket(self, auto_reconnect: bool = True):
         """Open tcp socket on provided path.
-        Tries to connect again if ConnectionRefusedError is raised
+        Tries to connect again if the connection fails
         """
         tcp_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+
+        # Count the retries, to avoid flooding the log
+        retry = 0
+
         while True:
+            error_string = ""
             try:
+                tcp_socket.settimeout(TCP_TIMEOUT)
                 tcp_socket.connect(
                     (self._parsed_path.hostname, self._parsed_path.port or 11120)
                 )
-                tcp_socket.settimeout(TCP_TIMEOUT)
                 break
             except ConnectionRefusedError:
-                time.sleep(0.005)
-                continue
+                error_string = "Connection refused."
+            except TimeoutError:
+                error_string = "Timeout on TCP connection."
+            except OSError as os_error:
+                error_string = f"Error during connection: {os_error}."
+            if retry % 100 == 0:
+                logging.error(error_string)
+
+            if not auto_reconnect:
+                break
+            if retry % 100 == 0:
+                logging.warning("Retrying to connect ...")
+            retry = retry + 1
+            time.sleep(0.005)
+
         self._io_stream = tcp_socket
 
 
@@ -90,11 +107,11 @@ def iter_file(osef_stream: OsefStream, auto_reconnect: bool = True) -> Iterator[
     """
     while True:
         try:
-            frame_tlv = _read_next_tlv(osef_stream)
+            frame_tlv = read_next_tlv(osef_stream)
         except EOFError:
             if auto_reconnect and osef_stream.is_tcp:
-                logging.warning("connection lost: reopening socket")
-                osef_stream.open_socket()
+                logging.warning("Connection lost: reopening socket")
+                osef_stream.open_socket(auto_reconnect)
                 continue
             break
         except Exception:  # pylint: disable=broad-except
@@ -215,6 +232,22 @@ _STRUCT_FORMAT += "L"  # unsigned long        (field 'L' ie. 'Length')
 _STRUCT_FORMAT += "%ds"  # buffer of fixed size (field 'V' ie. 'Value')
 
 
+def read_next_tlv(osef_stream: OsefStream) -> Optional[_Tlv]:
+    """Read the next TLV from a binary stream (file or socket)"""
+    # Read header
+    struct = Struct(_STRUCT_FORMAT % 0)
+    blob = _read_from_file(osef_stream, struct.size)
+    # Parse Type and Length
+    read_tlv = _Tlv._make(struct.unpack_from(blob))
+
+    # Now that we know its length we can read the Value
+    struct = Struct(_STRUCT_FORMAT % read_tlv.length)
+    blob += _read_from_file(osef_stream, struct.size - len(blob))
+    read_tlv = _Tlv._make(struct.unpack_from(blob))
+
+    return read_tlv
+
+
 def _align_size(size: int) -> int:
     """Returned aligned size from tlv size"""
     alignment_size = 4
@@ -234,22 +267,6 @@ def _read_from_file(osef_stream: OsefStream, byte_number: int) -> bytes:
     return blob
 
 
-def _read_next_tlv(osef_stream: OsefStream) -> Optional[_Tlv]:
-    """Read the next TLV from a binary stream (file or socket)"""
-    # Read header
-    struct = Struct(_STRUCT_FORMAT % 0)
-    blob = _read_from_file(osef_stream, struct.size)
-    # Parse Type and Length
-    read_tlv = _Tlv._make(struct.unpack_from(blob))
-
-    # Now that we know its length we can read the Value
-    struct = Struct(_STRUCT_FORMAT % read_tlv.length)
-    blob += _read_from_file(osef_stream, struct.size - len(blob))
-    read_tlv = _Tlv._make(struct.unpack_from(blob))
-
-    return read_tlv
-
-
 def _parse_tlv_from_blob(blob: bytes, offset=0) -> Tuple[_Tlv, int]:
     """Parse a TLV from a binary blob"""
     # Unpack a first time to get Type and Length
