@@ -1,14 +1,14 @@
 """Types of the objects contained in the OSEF stream."""
 import uuid
 from collections import namedtuple
-from enum import Enum
+from enum import IntEnum, Enum
 from struct import Struct
 from typing import List
 
 import numpy as np
 
 
-class OsefTypes(Enum):
+class OsefTypes(IntEnum):
     """Outsight Node and Leaf types."""
 
     AUGMENTED_CLOUD = 1
@@ -66,6 +66,7 @@ class OsefTypes(Enum):
     DISTANCES = 53
     LIDAR_MODEL = 54
     SLAM_POSE_ARRAY = 55
+    ZONE_VERTICAL_LIMITS = 56
 
 
 class PerceptIds(Enum):
@@ -98,6 +99,7 @@ class TrackedObjectClassIds(Enum):
     TWO_WHEELER = 8
     MASK = 9
     NO_MASK = 10
+    LANDMARK = 11
 
 
 class LidarModelIds(Enum):
@@ -267,13 +269,15 @@ def _object_properties_parser(value: bytes) -> np.ndarray:
         ("oriented", bool),
         ("extrapolated", bool),
         ("has_valid_slam_pose", bool),
+        ("is_static", bool),
     ]
     if len(value) == 0:
         return np.array([], dtype=dtype)
 
     object_iter = Struct("<B").iter_unpack(value)
     property_list = [
-        (bool(c[0] & 0x1), bool(c[0] & 0x2), bool(c[0] & 0x4)) for c in object_iter
+        (bool(c[0] & 0x1), bool(c[0] & 0x2), bool(c[0] & 0x4), bool(c[0] & 0x8))
+        for c in object_iter
     ]
     return np.array(property_list, dtype=dtype)
 
@@ -552,6 +556,9 @@ outsight_types = {
     OsefTypes.SLAM_POSE_ARRAY.value: TypeInfo(
         "slam_pose_array", LeafInfo(_pose_array_parser)
     ),
+    OsefTypes.ZONE_VERTICAL_LIMITS.value: TypeInfo(
+        "zone_vertical_limits", LeafInfo(_get_array_parser(np.dtype(np.float32)))
+    ),
 }
 
 
